@@ -175,9 +175,9 @@ def read_fb_ads(my_app_id, my_app_secret, my_access_token,
 
 
 
-##################################
-########## GOOGLE ADS ############
-##################################
+#################################
+########## GOOGLE ADS ##########
+################################
 
 
 def read_google_ads(n_range = 7, 
@@ -203,4 +203,45 @@ def read_google_ads(n_range = 7,
     
     
     
+###################################
+########## AIRCALL CALLS ##########
+###################################
+
+
+
+def read_aircall_calls(token, api_key, #mandatory
+                      
+                      start = 7, end = 0 #optional
+                     ):
+    
+    from askdata.integrations import aircall_api
+    
+    aircall_calls = aircall_api.get_aircall_calls(token, api_key, start, end)
+    
+    return aircall_calls
+    
+    
+    
+#############################
+########## HUBSPOT ##########
+#############################
+    
+
+## hubspot deals
+
+def read_hubspot_deals(API_KEY, 
+                        
+                        #optional input
+                        n_days = 7):
+    
+    
+    from askdata.interations import hubspot_api
+    
+    deals_all_fiels = hubspot_api.get_hubspot_deals_all_fiels(API_KEY, n_days)
+    
+    return deals_all_fiels
+ 
+
+    
+    
     
\ No newline at end of file
